//图库模块

import {get,post} from './http'

/**
 * 图表详情
 * @param ChartInfoId 图表ID
 * @param DateType 时段筛选：1-00年至今; 2-10年至今; 3-15年至今; 4-21年至今; 5-指定区间; 6-指定年月至今; 7-18年至今; 8-19年至今; 9-20年至今
 * @param StartDate 自定义开始日期
 * @param EndDate 自定义结束日期
 * @param SeasonStartDate 季节性图表-开始日期
 * @param SeasonEndDate 季节性图表-结束日期
 * @param EdbInfoId 指标ID，多个用英文逗号隔开
 * @param Calendar 公历/农历
 * @param ChartType 图表样式 1-曲线图 2-季节性图表
 */
export const apiChartInfo=params=>{
    return get('/my_chart/getChartDetail',params)
}

/**
 * 图表列表
 * @param Keywords
 * @param ClassifyId
 * @param Page
 * @param Limit
 */
export const apiChartList=params=>{
    return get('/my_chart/getChartList',params)
}

/**
 * 获取当前图表前一个\后一个 
 * @param MyChartId 当前图表的MyChartId
 * @param ChartInfoId 
 */
export const apiChartBeforeAndNext=params=>{
    return get('/my_chart/getChartBeforeAndNext',params)
}

/**
 * 保存图表
 */
export const apiChartSave=params=>{
    return post('/my_chart/editChartInfo',params)
}

/**
 * 刷新图表
 * @param ChartInfoId
 */
export const apiChartRefresh=params=>{
    return post('/my_chart/refreshChartInfo',params)
}

/**
 * 小程序中我的图库中查看详情
 * @param ChartInfoId
 */
export const apiMyChartDetail=params=>{
    return get('/my_chart/detail',params)
}

/**
 * 图表是否收藏了
 * @param unique_code
 * @param authorization
 */
export const apiChartIsCollect=params=>{
    return get('/my_chart/is_collect',params)
}

/**
 * 收藏图表
 * unique_code:string,
    authorization:string,
    report_id:number,
    report_chapter_id:number
 */

export const apiChartCollect=params=>{
    return post('/my_chart/collect',params)
}

/**
 * 取消收藏
 */
export const apiChartCollectCancel=params=>{
    return post('/my_chart/collect_cancel',params)
}

/**
 * 我的图表中我的分类
 */
export const apiMyChartClassifyList=()=>{
    return get('/my_chart_classify/list',{})
}

/**
 * 我的图表关联分类
 * @param my_chart_id
 * @param classify_id
 */
export const apiMyChartRelateClassify=params=>{
    return post('/my_chart/relate_classify',params)
}

/**
 * 新增我的图库分类
 * @param classify_name
 */
export const apiMyChartClassifyAdd=params=>{
    return post('/my_chart_classify/add',params)
}

/**
 * 获取商品价格曲线数据/相关性图表数据
 * @param {*} ChartInfoId 
 * @returns 
 */
export const apiCommonChartDetail = params => {
    return get('/my_chart/common/detail',params)
}

/**
 * 刷新商品价格图
 * @param {*} ChartInfoId 
 * @returns 
 */
export const apiCommonChartRefresh = params => {
    return post('/my_chart/future_good/refreshChartInfo',params)
}

/**
 * 保存商品价格图
 * @param {*} ChartInfoId  LeftMin LeftMax
 * @returns 
 */
export const apiCommonChartSave = params => {
    return post('/my_chart/future_good/editChartInfo',params)
}

/**
 * 刷新相关性图
 * @param {*} ChartInfoId 
 * @returns 
 */
 export const apiRelevanceChartRefresh = params => {
    return post('/my_chart/correlation/refreshChartInfo',params)
}

/**
 * 获取我的图库中切换上一张下一张的数据
 * @param classify_id
 */
export const apiMyChartChangeChartList=params=>{
    return get('/my_chart/locate',params)
}